#!/bin/bash

# Let user input the password for the one session
read -s -p "Please input the password for sudo command: " PASSWD
echo

#Validate the correct password before the following steps:
echo $PASSWD | sudo -k -S true
if [ $? -ne 0 ]; then
    echo "Wrong password, exit!"
    exit 1
fi
echo
echo

#Default working directory
WORKING_DIR=buildmedia
read -p "Please input the working directory(default is $WORKING_DIR): " IN_NAME
if [ ! -z "$IN_NAME" -a "$IN_NAME" != " " ]; then
    WORKING_DIR=$IN_NAME
fi
WORKING_PATH=$HOME/$WORKING_DIR
echo "************************************************************************"
echo "    Current working directory is $WORKING_PATH"
echo "************************************************************************"

# Let user select if checkout the tested version
USE_TESTED=0
echo "The build process can checkout the tested commits that listed in the article or use the latest version in the repo."
read -p "Please input Yes to checkout the tested commit or return for the latest version: " USR_SEL
if [[ ( ${USR_SEL:0:1} == 'Y' ) || ( ${USR_SEL:0:1} == 'y' ) ]]
    then
        USE_TESTED=1
fi
echo "************************************************************************"
if [ $USE_TESTED -eq 1 ]
    then
        echo "The tested commit ID will be checked out."
    else 
        echo "The latest commit will be checked out"
fi
echo "************************************************************************"

echo
echo "************************************************************************"
echo "    Start building Media SDK Open Source Software Stack"
echo "    Install required tools and create build environment."
echo "************************************************************************"
echo "......"

#Install the necessary tools
echo $PASSWD | sudo -k -S apt-get -y install git libssl-dev dh-autoreconf cmake libgl1-mesa-dev libpciaccess-dev
echo $PASSWD | sudo -k -S apt-get update

# Create the working directory
if [ ! -d "$WORKING_PATH" ]; then
	mkdir $WORKING_PATH
else
	echo Directory $WORKING_PATH exists
fi

# Create the build directory for UMD
if [ ! -d "$WORKING_PATH/build" ]; then
	mkdir -p $WORKING_PATH/build
else
	echo Directory $WORKING_PATH/build exists
fi

echo "************************************************************************"
echo "    Pull all the source code."
echo "************************************************************************"
echo "......"
# Pull all the source code
cd $WORKING_PATH
git clone https://github.com/01org/libva.git
git clone https://github.com/01org/libva-utils.git
git clone https://github.com/intel/media-driver.git
git clone https://github.com/intel/gmmlib.git
git clone https://github.com/Intel-Media-SDK/MediaSDK.git

echo "************************************************************************"
echo "    Build and Install libVA"
echo "************************************************************************"
echo "......"
# Build and install libVA including the libVA utils to validate the succeeful libVA build.
cd $WORKING_PATH/libva
if [ $USE_TESTED -eq 1 ]
    then
        git checkout fbf7138389f7d6adb6ca743d0ddf2dbc232895f6
fi
./autogen.sh --prefix=/usr --libdir=/usr/lib/x86_64-linux-gnu
make -j4
echo $PASSWD | sudo -k -S make install
cd $WORKING_PATH/libva-utils
if [ $USE_TESTED -eq 1 ]
    then
        git checkout 7b85ff442d99c233fb901a6fe3407d5308971645
fi
./autogen.sh --prefix=/usr --libdir=/usr/lib/x86_64-linux-gnu
make -j4
echo $PASSWD | sudo -k -S make install

echo "************************************************************************"
echo "    Build and Install media driver"
echo "************************************************************************"
echo "......"
# Build and install media driver
if [ $USE_TESTED -eq 1 ]
    then
        cd $WORKING_PATH/gmmlib
        git checkout b1451bbe4c506f17ddc819f12b4b448fc08698c5
        cd $WORKING_PATH/media-driver
        git checkout 2eab2e248c5787ceaebd76be791e60e28e56fbf3
fi
cd $WORKING_PATH/build
cmake ../media-driver -DMEDIA_VERSION="2.0.0" -DBUILD_ALONG_WITH_CMRTLIB=1 -DBS_DIR_GMMLIB=`pwd`/../gmmlib/Source/GmmLib/ -DBS_DIR_COMMON=`pwd`/../gmmlib/Source/Common/ -DBS_DIR_INC=`pwd`/../gmmlib/Source/inc/ -DBS_DIR_MEDIA=`pwd`/../media-driver -DCMAKE_INSTALL_PREFIX=/usr -DCMAKE_INSTALL_LIBDIR=/usr/lib/x86_64-linux-gnu -DINSTALL_DRIVER_SYSCONF=OFF -DLIBVA_DRIVERS_PATH=/usr/lib/x86_64-linux-gnu/dri
make -j8
echo $PASSWD | sudo -k -S make install

echo "************************************************************************"
echo "    Build and Install Media SDK and samples"
echo "************************************************************************"
echo "......"
# Build and install Media SDK library and samples
cd $WORKING_PATH/MediaSDK
if [ $USE_TESTED -eq 1 ]
    then
        git checkout e54022c1dbdcbd93b502f0da37352c9e9d103180
fi
export MFX_HOME=`pwd`
perl tools/builder/build_mfx.pl --cmake=intel64.make.release
make -C __cmake/intel64.make.release/ -j4
cd $WORKING_PATH/MediaSDK/__cmake/intel64.make.release
echo $PASSWD | sudo -k -S make install

export LIBVA_DRIVER_NAME=iHD
export LIBVA_DRIVERS_PATH=/usr/lib/x86_64-linux-gnu/dri
vainfo
echo "************************************************************************"
echo "    Build completed!"
echo "    Please check vainfo output to see if the build succeed"
echo "************************************************************************"


